<?php

// Copyright (c) 2008-2009 Nagios Enterprises, LLC.  All rights reserved.
//  
// $Id: bpi.inc.php 75 2010-04-01 19:40:08Z mguthrie $

include_once(dirname(__FILE__).'/../dashlethelper.inc.php');

bpi_dashlet_init();


function bpi_dashlet_init(){
	
	// respect the name!
	$name="bpi";
	
	$args=array(

		// need a name
		DASHLET_NAME => $name,
		
		// informative information
		DASHLET_VERSION => "1.1",
		DASHLET_DATE => "08-09-2012",
		DASHLET_AUTHOR => "Mike Guthrie, Nagios Enterprises, LLC",
		DASHLET_DESCRIPTION => gettext("Nagios XI Servers Only.")." ".gettext("This dashlet displays service status information for Nagios BPI Groups."),
		DASHLET_COPYRIGHT => "Copyright (c) 2009-2012 Nagios Enterprises",
		DASHLET_HOMEPAGE => "http://www.nagios.com",
		
		// the good stuff - only one output method is used.  order of preference is 1) function, 2) url
		DASHLET_FUNCTION => "bpi_dashlet_func",
		
		DASHLET_TITLE => gettext("BPI Status"),
		
		DASHLET_OUTBOARD_CLASS => "bpi_outboardclass",
		DASHLET_INBOARD_CLASS => "bpi_inboardclass",
		DASHLET_PREVIEW_CLASS => "bpi_previewclass",
		DASHLET_WIDTH => "400px",
		DASHLET_HEIGHT => "100px",
		
		DASHLET_REFRESHRATE => get_option('active_poller_interval')+1,
		);
	register_dashlet($name,$args);
	}



function bpi_dashlet_func($mode=DASHLET_MODE_PREVIEW,$id="",$args=null){
	$output="";	

	//array_dump($args); 

	switch($mode){
		case DASHLET_MODE_GETCONFIGHTML:
			$optionlist = '<option value="">'.gettext('Select A Server').'</option>'; 
			foreach(get_servers() as $key => $val) {
				if($val['type']!='nagiosxi') continue; //only works for XI 
				$optionlist.="<option value='{$key}'>{$val['name']}</option>\n"; 
			}

			$output='
				
			<br />
			<label for="server">'.gettext('Server').': </label><br class="nobr" />
			<select name="sid" id="sid">
				'.$optionlist.'
			</select><br class="nobr" />		 				
			<br class="nobr" />
							
			'; 
			
			break;
		case DASHLET_MODE_OUTBOARD:
			$args['mode']=$mode;
			$output.=bpi_dashlet_html($args);
			break; 
		case DASHLET_MODE_INBOARD:
			$args['mode']=$mode; //main Top Alert Producers page will override this
			$output.=bpi_dashlet_html($args);
			break;
		case DASHLET_MODE_PREVIEW:
			$output="<img src='".get_base_url()."/includes/dashlets/bpi/bpi_preview.png' height='75' />";
			break;
		}
	//$output.="<p>MODE: $mode, ID: $id</p>";
		
	return $output;
}

function bpi_dashlet_html($args=array()) {

	$id="bpi_dashlet_".random_string(6);
	// ajax updater args
	$ajaxargs=$args;
	// build args for javascript
	$n=0;
	$jargs="{";
	foreach($ajaxargs as $var => $val){
		if($n>0)
			$jargs.=", ";
		$jargs.="\"$var\" : \"$val\"";
		$n++;
		}
	$jargs.="}";	
	$img = theme_image('throbber.gif');
	
	//echo $jargs; 

	$output=<<<OUTPUT

<div class='bpicontainer'>
	<div class="fusioncore_bpi" id="{$id}">
	<img src="{$img}" />
	</div>

	<script type="text/javascript">
	$(document).ready(function(){

		get_bpi_content();
			
		$("#{$id}").everyTime(60*1000, "timer-fusioncore_bpi", function(i) {
			get_bpi_content();
		});
		
		function get_bpi_content(){
						
			$("#{$id}").each(function(){
				var optsarr = {
					"func": "get_bpi_html",
					"args": $jargs
					}
				var opts=array2json(optsarr);
				get_ajax_data_innerHTML("getfusioncoreajax",opts,true,this);
				});
			}		
	});
	</script>



</div> <!-- end bpicontainer -->

OUTPUT;

	return $output; 

}


function fusioncore_ajax_get_bpi_html($args=array()) {
	//array_dump($args);
	$sid = grab_array_var($args,'sid');
	$show = grab_array_var($args,'show','all'); 
	$sinfo=get_server_info($sid);
	$name = $sinfo['name']; 
	
	//array_dump($sinfo); 
	
	//build URL call 
	$baseurl=$sinfo["url"];
	$url = get_nagiosxi_backend_url($sid); 
	$url = str_replace('backend/?','',$url); 
	//remove backend from URL
	$parts = explode('&',$url);		
	$newurl=$baseurl."includes/components/nagiosbpi/bpi_display.php?cmd=getbpixml"; 
	for($i=1; $i<count($parts);$i++) {
		$newurl.="&".$parts[$i]; 
	}
	//echo $newurl; 

	$arr = get_server_data_from_url($newurl); 
	$xml = simplexml_load_string($arr['body']); 

	if(!$xml) return;  
	
	//bpi URL
	$bpi_url = $baseurl.'/includes/components/nagiosbpi/index.php'; 
	
	//array_dump($xml); 
	$output="<div class='bpi_dashlet_div'>
			<a href='{$bpi_url}' title='Access Nagios BPI' target='_blank'>".gettext("Access Nagios BPI on")." {$name}</a><br /> \n"; 

	foreach($xml->group as $group) {
		switch(intval($group->current_state)) {
			case 2:
				$state = 'CRITICAL'; 
			break; 
			case 1:
				$state = 'WARNING';
			break; 
			default:
				$state='OK'; 
			break; 
		}
		$output.="<table class='standardtable' style='margin-bottom:2px;'><tr>
				<td class='{$state}'><div style='width:60px;text-align:center;'>{$state}</div></td>
				<td>{$group->title}</td>
				<td>{$group->status_text}</td>
				</tr></table>"; 
	
	
	}
	$output.="</div>";
	$output.=gettext("Last Update").": ".date('r');

	return $output; 

}


?>